@@ -1,13 +1,7 @@
 /** @file
 
-  Copyright (c) 2014 - 2018, Intel Corporation. All rights reserved.<BR>
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php.
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  Copyright (c) 2014 - 2022, Intel Corporation. All rights reserved.<BR>
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -36,21 +30,36 @@ typedef struct {
   UINT16    IdtrLimit;
   UINT32    IdtrBase;
   UINT16    Reserved;
-  UINT32    Edi;
-  UINT32    Esi;
-  UINT32    Ebp;
-  UINT32    Esp;
-  UINT32    Ebx;
-  UINT32    Edx;
-  UINT32    Ecx;
-  UINT32    Eax;
+  UINT32    Registers[8];   // General Purpose Registers: Edi, Esi, Ebp, Esp, Ebx, Edx, Ecx and Eax
   UINT16    Flags[2];
   UINT32    FspInfoHeader;
   UINT32    ApiRet;
   UINT32    ApiParam[2];
 } CONTEXT_STACK;
 
-#define CONTEXT_STACK_OFFSET(x)  (UINT32)&((CONTEXT_STACK *)(UINTN)0)->x
+//
+//   API return address           +0xB8
+//   Reserved                     +0xB0
+//   push    API Parameter2       +0xA8
+//   push    API Parameter1       +0xA0
+//   push    FspInfoHeader        +0x98
+//   pushfq                       +0x90
+//   cli
+//   PUSHA_64                     +0x10
+//   sub     rsp, 16              +0x00
+//   sidt    [rsp]
+//
+typedef struct {
+  UINT64    Idtr[2];        // IDTR Limit - bit0:bi15, IDTR Base - bit16:bit79
+  UINT64    Registers[16];  // General Purpose Registers: RDI, RSI, RBP, RSP, RBX, RDX, RCX, RAX, and R15 to R8
+  UINT32    Flags[2];
+  UINT64    FspInfoHeader;
+  UINT64    ApiParam[2];
+  UINT64    Reserved;       // The reserved QWORD is needed for stack alignment in X64.
+  UINT64    ApiRet;         // 64bit stack format is different from the 32bit one due to x64 calling convention
+} CONTEXT_STACK_64;
+
+#define CONTEXT_STACK_OFFSET(x)  (sizeof(UINTN) == sizeof (UINT32) ? (UINTN)&((CONTEXT_STACK *)(UINTN)0)->x : (UINTN)&((CONTEXT_STACK_64 *)(UINTN)0)->x)
 
 #pragma pack()
 
@@ -63,11 +72,11 @@ typedef struct {
 VOID
 EFIAPI
 SetFspGlobalDataPointer (
-  IN FSP_GLOBAL_DATA   *FspData
+  IN FSP_GLOBAL_DATA  *FspData
   )
 {
   ASSERT (FspData != NULL);
-  *((volatile UINT32 *)(UINTN)PcdGet32(PcdGlobalDataPointerAddress)) = (UINT32)(UINTN)FspData;
+  *((volatile UINT32 *)(UINTN)PcdGet32 (PcdGlobalDataPointerAddress)) = (UINT32)(UINTN)FspData;
 }
 
 /**
@@ -80,18 +89,18 @@ GetFspGlobalDataPointer (
   VOID
   )
 {
-  FSP_GLOBAL_DATA   *FspData;
+  FSP_GLOBAL_DATA  *FspData;
 
-  FspData = *(FSP_GLOBAL_DATA  **)(UINTN)PcdGet32(PcdGlobalDataPointerAddress);
+  FspData = *(FSP_GLOBAL_DATA  **)(UINTN)PcdGet32 (PcdGlobalDataPointerAddress);
   return FspData;
 }
 
 /**
-  This function gets back the FSP API first parameter passed by the bootlaoder.
+  This function gets back the FSP API first parameter passed by the bootloader.
 
-  @retval ApiParameter FSP API first parameter passed by the bootlaoder.
+  @retval ApiParameter FSP API first parameter passed by the bootloader.
 **/
-UINT32
+UINTN
 EFIAPI
 GetFspApiParameter (
   VOID
@@ -99,16 +108,33 @@ GetFspApiParameter (
 {
   FSP_GLOBAL_DATA  *FspData;
 
-  FspData  = GetFspGlobalDataPointer ();
-  return *(UINT32 *)(UINTN)(FspData->CoreStack + CONTEXT_STACK_OFFSET(ApiParam[0]));
+  FspData = GetFspGlobalDataPointer ();
+  return *(UINTN *)(FspData->CoreStack + CONTEXT_STACK_OFFSET (ApiParam[0]));
 }
 
 /**
-  This function gets back the FSP API second parameter passed by the bootlaoder.
+  This function returns the FSP entry stack pointer from address of the first API parameter.
 
-  @retval ApiParameter FSP API second parameter passed by the bootlaoder.
+  @retval FSP entry stack pointer.
 **/
-UINT32
+VOID *
+EFIAPI
+GetFspEntryStack (
+  VOID
+  )
+{
+  FSP_GLOBAL_DATA  *FspData;
+
+  FspData = GetFspGlobalDataPointer ();
+  return (VOID *)(FspData->CoreStack + CONTEXT_STACK_OFFSET (ApiParam[0]));
+}
+
+/**
+  This function gets back the FSP API second parameter passed by the bootloader.
+
+  @retval ApiParameter FSP API second parameter passed by the bootloader.
+**/
+UINTN
 EFIAPI
 GetFspApiParameter2 (
   VOID
@@ -116,8 +142,8 @@ GetFspApiParameter2 (
 {
   FSP_GLOBAL_DATA  *FspData;
 
-  FspData  = GetFspGlobalDataPointer ();
-  return *(UINT32 *)(UINTN)(FspData->CoreStack + CONTEXT_STACK_OFFSET(ApiParam[1]));
+  FspData = GetFspGlobalDataPointer ();
+  return *(UINTN *)(FspData->CoreStack + CONTEXT_STACK_OFFSET (ApiParam[1]));
 }
 
 /**
@@ -129,13 +155,13 @@ GetFspApiParameter2 (
 VOID
 EFIAPI
 SetFspApiParameter (
-  IN UINT32      Value
+  IN UINT32  Value
   )
 {
   FSP_GLOBAL_DATA  *FspData;
 
-  FspData  = GetFspGlobalDataPointer ();
-  *(UINT32 *)(UINTN)(FspData->CoreStack + CONTEXT_STACK_OFFSET(ApiParam)) = Value;
+  FspData                                                          = GetFspGlobalDataPointer ();
+  *(UINTN *)(FspData->CoreStack + CONTEXT_STACK_OFFSET (ApiParam)) = Value;
 }
 
 /**
@@ -147,13 +173,13 @@ SetFspApiParameter (
 VOID
 EFIAPI
 SetFspApiReturnStatus (
-  IN UINT32  ReturnStatus
+  IN UINTN  ReturnStatus
   )
 {
   FSP_GLOBAL_DATA  *FspData;
 
-  FspData  = GetFspGlobalDataPointer ();
-  *(UINT32 *)(UINTN)(FspData->CoreStack + CONTEXT_STACK_OFFSET(Eax)) = ReturnStatus;
+  FspData                                                              = GetFspGlobalDataPointer ();
+  *(UINTN *)(FspData->CoreStack + CONTEXT_STACK_OFFSET (Registers[7])) = ReturnStatus;
 }
 
 /**
@@ -165,23 +191,23 @@ SetFspApiReturnStatus (
 VOID
 EFIAPI
 SetFspCoreStackPointer (
-  IN VOID   *NewStackTop
+  IN VOID  *NewStackTop
   )
 {
   FSP_GLOBAL_DATA  *FspData;
-  UINT32           *OldStack;
-  UINT32           *NewStack;
+  UINTN            *OldStack;
+  UINTN            *NewStack;
   UINT32           StackContextLen;
 
-  FspData  = GetFspGlobalDataPointer ();
-  StackContextLen = sizeof(CONTEXT_STACK) / sizeof(UINT32);
+  FspData         = GetFspGlobalDataPointer ();
+  StackContextLen = sizeof(CONTEXT_STACK) / sizeof(UINTN);
 
   //
   // Reserve space for the ContinuationFunc two parameters
   //
-  OldStack = (UINT32 *)FspData->CoreStack;
-  NewStack = (UINT32 *)NewStackTop - StackContextLen - 2;
-  FspData->CoreStack = (UINT32)NewStack;
+  OldStack = (UINTN *)FspData->CoreStack;
+  NewStack = (UINTN *)NewStackTop - StackContextLen - 2;
+  FspData->CoreStack = (UINTN)NewStack;
   while (StackContextLen-- != 0) {
     *NewStack++ = *OldStack++;
   }
@@ -196,16 +222,15 @@ SetFspCoreStackPointer (
 VOID
 EFIAPI
 SetFspPlatformDataPointer (
-  IN VOID   *PlatformData
+  IN VOID  *PlatformData
   )
 {
   FSP_GLOBAL_DATA  *FspData;
 
-  FspData  = GetFspGlobalDataPointer ();
+  FspData                       = GetFspGlobalDataPointer ();
   FspData->PlatformData.DataPtr = PlatformData;
 }
 
-
 /**
   This function gets the platform specific data pointer.
 
@@ -220,11 +245,10 @@ GetFspPlatformDataPointer (
 {
   FSP_GLOBAL_DATA  *FspData;
 
-  FspData  = GetFspGlobalDataPointer ();
+  FspData = GetFspGlobalDataPointer ();
   return FspData->PlatformData.DataPtr;
 }
 
-
 /**
   This function sets the UPD data pointer.
 
@@ -233,7 +257,7 @@ GetFspPlatformDataPointer (
 VOID
 EFIAPI
 SetFspUpdDataPointer (
-  IN VOID    *UpdDataPtr
+  IN VOID  *UpdDataPtr
   )
 {
   FSP_GLOBAL_DATA  *FspData;
@@ -241,7 +265,7 @@ SetFspUpdDataPointer (
   //
   // Get the FSP Global Data Pointer
   //
-  FspData  = GetFspGlobalDataPointer ();
+  FspData = GetFspGlobalDataPointer ();
 
   //
   // Set the UPD pointer.
@@ -262,11 +286,10 @@ GetFspUpdDataPointer (
 {
   FSP_GLOBAL_DATA  *FspData;
 
-  FspData  = GetFspGlobalDataPointer ();
+  FspData = GetFspGlobalDataPointer ();
   return FspData->UpdDataPtr;
 }
 
-
 /**
   This function sets the FspMemoryInit UPD data pointer.
 
@@ -275,7 +298,7 @@ GetFspUpdDataPointer (
 VOID
 EFIAPI
 SetFspMemoryInitUpdDataPointer (
-  IN VOID    *MemoryInitUpdPtr
+  IN VOID  *MemoryInitUpdPtr
   )
 {
   FSP_GLOBAL_DATA  *FspData;
@@ -283,7 +306,7 @@ SetFspMemoryInitUpdDataPointer (
   //
   // Get the FSP Global Data Pointer
   //
-  FspData  = GetFspGlobalDataPointer ();
+  FspData = GetFspGlobalDataPointer ();
 
   //
   // Set the FspMemoryInit UPD pointer.
@@ -304,11 +327,10 @@ GetFspMemoryInitUpdDataPointer (
 {
   FSP_GLOBAL_DATA  *FspData;
 
-  FspData  = GetFspGlobalDataPointer ();
+  FspData = GetFspGlobalDataPointer ();
   return FspData->MemoryInitUpdPtr;
 }
 
-
 /**
   This function sets the FspSiliconInit UPD data pointer.
 
@@ -317,7 +339,7 @@ GetFspMemoryInitUpdDataPointer (
 VOID
 EFIAPI
 SetFspSiliconInitUpdDataPointer (
-  IN VOID    *SiliconInitUpdPtr
+  IN VOID  *SiliconInitUpdPtr
   )
 {
   FSP_GLOBAL_DATA  *FspData;
@@ -325,7 +347,7 @@ SetFspSiliconInitUpdDataPointer (
   //
   // Get the FSP Global Data Pointer
   //
-  FspData  = GetFspGlobalDataPointer ();
+  FspData = GetFspGlobalDataPointer ();
 
   //
   // Set the FspSiliconInit UPD data pointer.
@@ -346,11 +368,10 @@ GetFspSiliconInitUpdDataPointer (
 {
   FSP_GLOBAL_DATA  *FspData;
 
-  FspData  = GetFspGlobalDataPointer ();
+  FspData = GetFspGlobalDataPointer ();
   return FspData->SiliconInitUpdPtr;
 }
 
-
 /**
   Set FSP measurement point timestamp.
 
@@ -370,9 +391,9 @@ SetFspMeasurePoint (
   // Bit [55: 0]  will be the timestamp
   // Bit [63:56]  will be the ID
   //
-  FspData  = GetFspGlobalDataPointer ();
-  if (FspData->PerfIdx < sizeof(FspData->PerfData) / sizeof(FspData->PerfData[0])) {
-    FspData->PerfData[FspData->PerfIdx] = AsmReadTsc ();
+  FspData = GetFspGlobalDataPointer ();
+  if (FspData->PerfIdx < sizeof (FspData->PerfData) / sizeof (FspData->PerfData[0])) {
+    FspData->PerfData[FspData->PerfIdx]                  = AsmReadTsc ();
     ((UINT8 *)(&FspData->PerfData[FspData->PerfIdx]))[7] = Id;
   }
 
@@ -390,7 +411,7 @@ GetFspInfoHeader (
   VOID
   )
 {
-  return  GetFspGlobalDataPointer()->FspInfoHeader;
+  return GetFspGlobalDataPointer ()->FspInfoHeader;
 }
 
 /**
@@ -401,10 +422,10 @@ GetFspInfoHeader (
 VOID
 EFIAPI
 SetFspInfoHeader (
-  FSP_INFO_HEADER *FspInfoHeader
+  FSP_INFO_HEADER  *FspInfoHeader
   )
 {
-  GetFspGlobalDataPointer()->FspInfoHeader = FspInfoHeader;
+  GetFspGlobalDataPointer ()->FspInfoHeader = FspInfoHeader;
 }
 
 /**
@@ -420,8 +441,8 @@ GetFspInfoHeaderFromApiContext (
 {
   FSP_GLOBAL_DATA  *FspData;
 
-  FspData  = GetFspGlobalDataPointer ();
-  return  (FSP_INFO_HEADER *)(*(UINT32 *)(UINTN)(FspData->CoreStack + CONTEXT_STACK_OFFSET(FspInfoHeader)));
+  FspData = GetFspGlobalDataPointer ();
+  return (FSP_INFO_HEADER *)(*(UINTN *)(FspData->CoreStack + CONTEXT_STACK_OFFSET (FspInfoHeader)));
 }
 
 /**
@@ -435,10 +456,10 @@ GetFspCfgRegionDataPointer (
   VOID
   )
 {
-  FSP_INFO_HEADER   *FspInfoHeader;
+  FSP_INFO_HEADER  *FspInfoHeader;
 
   FspInfoHeader = GetFspInfoHeader ();
-  return (VOID *)(FspInfoHeader->ImageBase + FspInfoHeader->CfgRegionOffset);
+  return (VOID *)(UINTN)(FspInfoHeader->ImageBase + FspInfoHeader->CfgRegionOffset);
 }
 
 /**
@@ -452,7 +473,7 @@ GetFspApiCallingIndex (
   VOID
   )
 {
-  return  GetFspGlobalDataPointer()->ApiIdx;
+  return GetFspGlobalDataPointer ()->ApiIdx;
 }
 
 /**
@@ -468,7 +489,7 @@ SetFspApiCallingIndex (
 {
   FSP_GLOBAL_DATA  *FspData;
 
-  FspData  = GetFspGlobalDataPointer ();
+  FspData         = GetFspGlobalDataPointer ();
   FspData->ApiIdx = Index;
 }
 
@@ -483,7 +504,7 @@ GetPhaseStatusCode (
   VOID
   )
 {
-  return  GetFspGlobalDataPointer()->StatusCode;
+  return GetFspGlobalDataPointer ()->StatusCode;
 }
 
 /**
@@ -499,7 +520,7 @@ SetPhaseStatusCode (
 {
   FSP_GLOBAL_DATA  *FspData;
 
-  FspData  = GetFspGlobalDataPointer ();
+  FspData             = GetFspGlobalDataPointer ();
   FspData->StatusCode = StatusCode;
 }
 
@@ -512,13 +533,13 @@ SetPhaseStatusCode (
 VOID
 EFIAPI
 FspApiReturnStatusReset (
-  IN UINT32   FspResetType
+  IN UINT32  FspResetType
   )
 {
   volatile BOOLEAN  LoopUntilReset;
 
   LoopUntilReset = TRUE;
-  DEBUG ((DEBUG_INFO, "FSP returning control to Bootloader with reset required return status %x\n",FspResetType));
+  DEBUG ((DEBUG_INFO, "FSP returning control to Bootloader with reset required return status %x\n", FspResetType));
   if (GetFspGlobalDataPointer ()->FspMode == FSP_IN_API_MODE) {
     ///
     /// Below code is not an infinite loop.The control will go back to API calling function in BootLoader each time BootLoader
