@@ -50,51 +50,51 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 /// It is an FFS type extension used for PeiFindFileEx. It indicates current
 /// FFS searching is for all PEIMs can be dispatched by PeiCore.
 ///
-#define PEI_CORE_INTERNAL_FFS_FILE_DISPATCH_TYPE   0xff
+#define PEI_CORE_INTERNAL_FFS_FILE_DISPATCH_TYPE  0xff
 
 ///
 /// Pei Core private data structures
 ///
 typedef union {
-  EFI_PEI_PPI_DESCRIPTOR      *Ppi;
-  EFI_PEI_NOTIFY_DESCRIPTOR   *Notify;
-  VOID                        *Raw;
+  EFI_PEI_PPI_DESCRIPTOR       *Ppi;
+  EFI_PEI_NOTIFY_DESCRIPTOR    *Notify;
+  VOID                         *Raw;
 } PEI_PPI_LIST_POINTERS;
 
 ///
 /// Number of PEI_PPI_LIST_POINTERS to grow by each time we run out of room
 ///
-#define PPI_GROWTH_STEP             64
-#define CALLBACK_NOTIFY_GROWTH_STEP 32
-#define DISPATCH_NOTIFY_GROWTH_STEP 8
+#define PPI_GROWTH_STEP              64
+#define CALLBACK_NOTIFY_GROWTH_STEP  32
+#define DISPATCH_NOTIFY_GROWTH_STEP  8
 
 typedef struct {
-  UINTN                 CurrentCount;
-  UINTN                 MaxCount;
-  UINTN                 LastDispatchedCount;
+  UINTN                    CurrentCount;
+  UINTN                    MaxCount;
+  UINTN                    LastDispatchedCount;
   ///
   /// MaxCount number of entries.
   ///
-  PEI_PPI_LIST_POINTERS *PpiPtrs;
+  PEI_PPI_LIST_POINTERS    *PpiPtrs;
 } PEI_PPI_LIST;
 
 typedef struct {
-  UINTN                 CurrentCount;
-  UINTN                 MaxCount;
+  UINTN                    CurrentCount;
+  UINTN                    MaxCount;
   ///
   /// MaxCount number of entries.
   ///
-  PEI_PPI_LIST_POINTERS *NotifyPtrs;
+  PEI_PPI_LIST_POINTERS    *NotifyPtrs;
 } PEI_CALLBACK_NOTIFY_LIST;
 
 typedef struct {
-  UINTN                 CurrentCount;
-  UINTN                 MaxCount;
-  UINTN                 LastDispatchedCount;
+  UINTN                    CurrentCount;
+  UINTN                    MaxCount;
+  UINTN                    LastDispatchedCount;
   ///
   /// MaxCount number of entries.
   ///
-  PEI_PPI_LIST_POINTERS *NotifyPtrs;
+  PEI_PPI_LIST_POINTERS    *NotifyPtrs;
 } PEI_DISPATCH_NOTIFY_LIST;
 
 ///
@@ -105,15 +105,15 @@ typedef struct {
   ///
   /// PPI List.
   ///
-  PEI_PPI_LIST              PpiList;
+  PEI_PPI_LIST                PpiList;
   ///
   /// Notify List at dispatch level.
   ///
-  PEI_CALLBACK_NOTIFY_LIST  CallbackNotifyList;
+  PEI_CALLBACK_NOTIFY_LIST    CallbackNotifyList;
   ///
   /// Notify List at callback level.
   ///
-  PEI_DISPATCH_NOTIFY_LIST  DispatchNotifyList;
+  PEI_DISPATCH_NOTIFY_LIST    DispatchNotifyList;
 } PEI_PPI_DATABASE;
 
 //
@@ -121,64 +121,63 @@ typedef struct {
 // Do not change these values as there is code doing math to change states.
 // Look for Private->Fv[FvCount].PeimState[PeimCount]++;
 //
-#define PEIM_STATE_NOT_DISPATCHED         0x00
-#define PEIM_STATE_DISPATCHED             0x01
-#define PEIM_STATE_REGISTER_FOR_SHADOW    0x02
-#define PEIM_STATE_DONE                   0x03
+#define PEIM_STATE_NOT_DISPATCHED       0x00
+#define PEIM_STATE_DISPATCHED           0x01
+#define PEIM_STATE_REGISTER_FOR_SHADOW  0x02
+#define PEIM_STATE_DONE                 0x03
 
 //
 // Number of FV instances to grow by each time we run out of room
 //
-#define FV_GROWTH_STEP 8
+#define FV_GROWTH_STEP  8
 
 typedef struct {
-  EFI_FIRMWARE_VOLUME_HEADER          *FvHeader;
-  EFI_PEI_FIRMWARE_VOLUME_PPI         *FvPpi;
-  EFI_PEI_FV_HANDLE                   FvHandle;
-  UINTN                               PeimCount;
+  EFI_FIRMWARE_VOLUME_HEADER     *FvHeader;
+  EFI_PEI_FIRMWARE_VOLUME_PPI    *FvPpi;
+  EFI_PEI_FV_HANDLE              FvHandle;
+  UINTN                          PeimCount;
   //
   // Pointer to the buffer with the PeimCount number of Entries.
   //
-  UINT8                               *PeimState;
+  UINT8                          *PeimState;
   //
   // Pointer to the buffer with the PeimCount number of Entries.
   //
-  EFI_PEI_FILE_HANDLE                 *FvFileHandles;
-  BOOLEAN                             ScanFv;
-  UINT32                              AuthenticationStatus;
+  EFI_PEI_FILE_HANDLE            *FvFileHandles;
+  BOOLEAN                        ScanFv;
+  UINT32                         AuthenticationStatus;
 } PEI_CORE_FV_HANDLE;
 
 typedef struct {
-  EFI_GUID                            FvFormat;
-  VOID                                *FvInfo;
-  UINT32                              FvInfoSize;
-  UINT32                              AuthenticationStatus;
-  EFI_PEI_NOTIFY_DESCRIPTOR           NotifyDescriptor;
+  EFI_GUID                     FvFormat;
+  VOID                         *FvInfo;
+  UINT32                       FvInfoSize;
+  UINT32                       AuthenticationStatus;
+  EFI_PEI_NOTIFY_DESCRIPTOR    NotifyDescriptor;
 } PEI_CORE_UNKNOW_FORMAT_FV_INFO;
 
-#define CACHE_SETION_MAX_NUMBER       0x10
+#define CACHE_SETION_MAX_NUMBER  0x10
 typedef struct {
-  EFI_COMMON_SECTION_HEADER*          Section[CACHE_SETION_MAX_NUMBER];
-  VOID*                               SectionData[CACHE_SETION_MAX_NUMBER];
-  UINTN                               SectionSize[CACHE_SETION_MAX_NUMBER];
-  UINT32                              AuthenticationStatus[CACHE_SETION_MAX_NUMBER];
-  UINTN                               AllSectionCount;
-  UINTN                               SectionIndex;
+  EFI_COMMON_SECTION_HEADER    *Section[CACHE_SETION_MAX_NUMBER];
+  VOID                         *SectionData[CACHE_SETION_MAX_NUMBER];
+  UINTN                        SectionSize[CACHE_SETION_MAX_NUMBER];
+  UINT32                       AuthenticationStatus[CACHE_SETION_MAX_NUMBER];
+  UINTN                        AllSectionCount;
+  UINTN                        SectionIndex;
 } CACHE_SECTION_DATA;
 
-#define HOLE_MAX_NUMBER       0x3
+#define HOLE_MAX_NUMBER  0x3
 typedef struct {
-  EFI_PHYSICAL_ADDRESS               Base;
-  UINTN                              Size;
-  UINTN                              Offset;
-  BOOLEAN                            OffsetPositive;
+  EFI_PHYSICAL_ADDRESS    Base;
+  UINTN                   Size;
+  UINTN                   Offset;
+  BOOLEAN                 OffsetPositive;
 } HOLE_MEMORY_DATA;
 
 ///
 /// Forward declaration for PEI_CORE_INSTANCE
 ///
-typedef struct _PEI_CORE_INSTANCE  PEI_CORE_INSTANCE;
-
+typedef struct _PEI_CORE_INSTANCE PEI_CORE_INSTANCE;
 
 /**
   Function Pointer type for PeiCore function.
@@ -204,7 +203,7 @@ EFI_STATUS
 //
 // Number of files to grow by each time we run out of room
 //
-#define TEMP_FILE_GROWTH_STEP 32
+#define TEMP_FILE_GROWTH_STEP  32
 
 #define PEI_CORE_HANDLE_SIGNATURE  SIGNATURE_32('P','e','i','C')
 
@@ -212,75 +211,75 @@ EFI_STATUS
 /// Pei Core private data structure instance
 ///
 struct _PEI_CORE_INSTANCE {
-  UINTN                              Signature;
+  UINTN                             Signature;
 
   ///
   /// Point to ServiceTableShadow
   ///
-  EFI_PEI_SERVICES                   *Ps;
-  PEI_PPI_DATABASE                   PpiData;
+  EFI_PEI_SERVICES                  *Ps;
+  PEI_PPI_DATABASE                  PpiData;
 
   ///
   /// The count of FVs which contains FFS and could be dispatched by PeiCore.
   ///
-  UINTN                              FvCount;
+  UINTN                             FvCount;
 
   ///
   /// The max count of FVs which contains FFS and could be dispatched by PeiCore.
   ///
-  UINTN                              MaxFvCount;
+  UINTN                             MaxFvCount;
 
   ///
   /// Pointer to the buffer with the MaxFvCount number of entries.
   /// Each entry is for one FV which contains FFS and could be dispatched by PeiCore.
   ///
-  PEI_CORE_FV_HANDLE                 *Fv;
+  PEI_CORE_FV_HANDLE                *Fv;
 
   ///
   /// Pointer to the buffer with the MaxUnknownFvInfoCount number of entries.
   /// Each entry is for one FV which could not be dispatched by PeiCore.
   ///
-  PEI_CORE_UNKNOW_FORMAT_FV_INFO     *UnknownFvInfo;
-  UINTN                              MaxUnknownFvInfoCount;
-  UINTN                              UnknownFvInfoCount;
+  PEI_CORE_UNKNOW_FORMAT_FV_INFO    *UnknownFvInfo;
+  UINTN                             MaxUnknownFvInfoCount;
+  UINTN                             UnknownFvInfoCount;
 
   ///
   /// Pointer to the buffer FvFileHandlers in PEI_CORE_FV_HANDLE specified by CurrentPeimFvCount.
   ///
-  EFI_PEI_FILE_HANDLE                *CurrentFvFileHandles;
-  UINTN                              AprioriCount;
-  UINTN                              CurrentPeimFvCount;
-  UINTN                              CurrentPeimCount;
-  EFI_PEI_FILE_HANDLE                CurrentFileHandle;
-  BOOLEAN                            PeimNeedingDispatch;
-  BOOLEAN                            PeimDispatchOnThisPass;
-  BOOLEAN                            PeimDispatcherReenter;
-  EFI_PEI_HOB_POINTERS               HobList;
-  BOOLEAN                            SwitchStackSignal;
-  BOOLEAN                            PeiMemoryInstalled;
-  VOID                               *CpuIo;
-  EFI_PEI_SECURITY2_PPI              *PrivateSecurityPpi;
-  EFI_PEI_SERVICES                   ServiceTableShadow;
-  EFI_PEI_PPI_DESCRIPTOR             *XipLoadFile;
-  EFI_PHYSICAL_ADDRESS               PhysicalMemoryBegin;
-  UINT64                             PhysicalMemoryLength;
-  EFI_PHYSICAL_ADDRESS               FreePhysicalMemoryTop;
-  UINTN                              HeapOffset;
-  BOOLEAN                            HeapOffsetPositive;
-  UINTN                              StackOffset;
-  BOOLEAN                            StackOffsetPositive;
+  EFI_PEI_FILE_HANDLE               *CurrentFvFileHandles;
+  UINTN                             AprioriCount;
+  UINTN                             CurrentPeimFvCount;
+  UINTN                             CurrentPeimCount;
+  EFI_PEI_FILE_HANDLE               CurrentFileHandle;
+  BOOLEAN                           PeimNeedingDispatch;
+  BOOLEAN                           PeimDispatchOnThisPass;
+  BOOLEAN                           PeimDispatcherReenter;
+  EFI_PEI_HOB_POINTERS              HobList;
+  BOOLEAN                           SwitchStackSignal;
+  BOOLEAN                           PeiMemoryInstalled;
+  VOID                              *CpuIo;
+  EFI_PEI_SECURITY2_PPI             *PrivateSecurityPpi;
+  EFI_PEI_SERVICES                  ServiceTableShadow;
+  EFI_PEI_PPI_DESCRIPTOR            *XipLoadFile;
+  EFI_PHYSICAL_ADDRESS              PhysicalMemoryBegin;
+  UINT64                            PhysicalMemoryLength;
+  EFI_PHYSICAL_ADDRESS              FreePhysicalMemoryTop;
+  UINTN                             HeapOffset;
+  BOOLEAN                           HeapOffsetPositive;
+  UINTN                             StackOffset;
+  BOOLEAN                           StackOffsetPositive;
   //
   // Information for migrating memory pages allocated in pre-memory phase.
   //
-  HOLE_MEMORY_DATA                   MemoryPages;
-  PEICORE_FUNCTION_POINTER           ShadowedPeiCore;
-  CACHE_SECTION_DATA                 CacheSection;
+  HOLE_MEMORY_DATA                  MemoryPages;
+  PEICORE_FUNCTION_POINTER          ShadowedPeiCore;
+  CACHE_SECTION_DATA                CacheSection;
   //
   // For Loading modules at fixed address feature to cache the top address below which the
   // Runtime code, boot time code and PEI memory will be placed. Please note that the offset between this field
   // and Ps should not be changed since maybe user could get this top address by using the offset to Ps.
   //
-  EFI_PHYSICAL_ADDRESS               LoadModuleAtFixAddressTopAddress;
+  EFI_PHYSICAL_ADDRESS              LoadModuleAtFixAddressTopAddress;
   //
   // The field is define for Loading modules at fixed address feature to tracker the PEI code
   // memory range usage. It is a bit mapped array in which every bit indicates the corresponding memory page
@@ -320,13 +319,13 @@ struct _PEI_CORE_INSTANCE {
 /// Union of temporarily used function pointers (to save stack space)
 ///
 typedef union {
-  PEICORE_FUNCTION_POINTER     PeiCore;
-  EFI_PEIM_ENTRY_POINT2        PeimEntry;
-  EFI_PEIM_NOTIFY_ENTRY_POINT  PeimNotifyEntry;
-  EFI_DXE_IPL_PPI              *DxeIpl;
-  EFI_PEI_PPI_DESCRIPTOR       *PpiDescriptor;
-  EFI_PEI_NOTIFY_DESCRIPTOR    *NotifyDescriptor;
-  VOID                         *Raw;
+  PEICORE_FUNCTION_POINTER       PeiCore;
+  EFI_PEIM_ENTRY_POINT2          PeimEntry;
+  EFI_PEIM_NOTIFY_ENTRY_POINT    PeimNotifyEntry;
+  EFI_DXE_IPL_PPI                *DxeIpl;
+  EFI_PEI_PPI_DESCRIPTOR         *PpiDescriptor;
+  EFI_PEI_NOTIFY_DESCRIPTOR      *NotifyDescriptor;
+  VOID                           *Raw;
 } PEI_CORE_TEMP_POINTERS;
 
 typedef struct {
@@ -338,6 +337,7 @@ typedef struct {
 //
 // PeiCore function
 //
+
 /**
 
   The entry routine to Pei Core, invoked by PeiMain during transition
@@ -360,9 +360,9 @@ typedef struct {
 VOID
 EFIAPI
 PeiCore (
-  IN CONST EFI_SEC_PEI_HAND_OFF        *SecCoreData,
-  IN CONST EFI_PEI_PPI_DESCRIPTOR      *PpiList,
-  IN VOID                              *Data
+  IN CONST EFI_SEC_PEI_HAND_OFF    *SecCoreData,
+  IN CONST EFI_PEI_PPI_DESCRIPTOR  *PpiList,
+  IN VOID                          *Data
   );
 
 //
@@ -391,8 +391,8 @@ PeiCore (
 **/
 BOOLEAN
 PeimDispatchReadiness (
-  IN EFI_PEI_SERVICES   **PeiServices,
-  IN VOID               *DependencyExpression
+  IN EFI_PEI_SERVICES  **PeiServices,
+  IN VOID              *DependencyExpression
   );
 
 /**
@@ -407,8 +407,8 @@ PeimDispatchReadiness (
 EFI_STATUS
 EFIAPI
 MigratePeim (
-  IN  EFI_PEI_FILE_HANDLE     FileHandle,
-  IN  EFI_PEI_FILE_HANDLE     MigratedFileHandle
+  IN  EFI_PEI_FILE_HANDLE  FileHandle,
+  IN  EFI_PEI_FILE_HANDLE  MigratedFileHandle
   );
 
 /**
@@ -419,15 +419,15 @@ MigratePeim (
                          environment, such as the size and location of temporary RAM, the stack location and
                          the BFV location.
 
-  @retval EFI_SUCCESS           Succesfully migrated installed FVs from temporary RAM to permanent memory.
+  @retval EFI_SUCCESS           Successfully migrated installed FVs from temporary RAM to permanent memory.
   @retval EFI_OUT_OF_RESOURCES  Insufficient memory exists to allocate needed pages.
 
 **/
 EFI_STATUS
 EFIAPI
 EvacuateTempRam (
-  IN PEI_CORE_INSTANCE            *Private,
-  IN CONST EFI_SEC_PEI_HAND_OFF   *SecCoreData
+  IN PEI_CORE_INSTANCE           *Private,
+  IN CONST EFI_SEC_PEI_HAND_OFF  *SecCoreData
   );
 
 /**
@@ -455,9 +455,9 @@ PeiDispatcher (
 **/
 VOID
 InitializeDispatcherData (
-  IN PEI_CORE_INSTANCE            *PrivateData,
-  IN PEI_CORE_INSTANCE            *OldCoreData,
-  IN CONST EFI_SEC_PEI_HAND_OFF   *SecCoreData
+  IN PEI_CORE_INSTANCE           *PrivateData,
+  IN PEI_CORE_INSTANCE           *OldCoreData,
+  IN CONST EFI_SEC_PEI_HAND_OFF  *SecCoreData
   );
 
 /**
@@ -475,14 +475,15 @@ InitializeDispatcherData (
 **/
 BOOLEAN
 DepexSatisfied (
-  IN PEI_CORE_INSTANCE          *Private,
-  IN EFI_PEI_FILE_HANDLE        FileHandle,
-  IN UINTN                      PeimCount
+  IN PEI_CORE_INSTANCE    *Private,
+  IN EFI_PEI_FILE_HANDLE  FileHandle,
+  IN UINTN                PeimCount
   );
 
 //
 // PPI support functions
 //
+
 /**
 
   Initialize PPI services.
@@ -494,8 +495,8 @@ DepexSatisfied (
 **/
 VOID
 InitializePpiServices (
-  IN PEI_CORE_INSTANCE   *PrivateData,
-  IN PEI_CORE_INSTANCE   *OldCoreData
+  IN PEI_CORE_INSTANCE  *PrivateData,
+  IN PEI_CORE_INSTANCE  *OldCoreData
   );
 
 /**
@@ -525,10 +526,10 @@ ConvertPpiPointers (
 **/
 VOID
 ConvertPpiPointersFv (
-  IN  PEI_CORE_INSTANCE       *PrivateData,
-  IN  UINTN                   OrgFvHandle,
-  IN  UINTN                   FvHandle,
-  IN  UINTN                   FvSize
+  IN  PEI_CORE_INSTANCE  *PrivateData,
+  IN  UINTN              OrgFvHandle,
+  IN  UINTN              FvHandle,
+  IN  UINTN              FvSize
   );
 
 /**
@@ -541,8 +542,8 @@ ConvertPpiPointersFv (
 **/
 VOID
 ConvertPeiCorePpiPointers (
-  IN  PEI_CORE_INSTANCE        *PrivateData,
-  PEI_CORE_FV_HANDLE           CoreFvHandle
+  IN  PEI_CORE_INSTANCE   *PrivateData,
+  IN  PEI_CORE_FV_HANDLE  *CoreFvHandle
   );
 
 /**
@@ -554,7 +555,7 @@ ConvertPeiCorePpiPointers (
 **/
 VOID
 DumpPpiList (
-  IN PEI_CORE_INSTANCE    *PrivateData
+  IN PEI_CORE_INSTANCE  *PrivateData
   );
 
 /**
@@ -672,11 +673,11 @@ ProcessDispatchNotifyList (
 VOID
 ProcessNotify (
   IN PEI_CORE_INSTANCE  *PrivateData,
-  IN UINTN               NotifyType,
-  IN INTN                InstallStartIndex,
-  IN INTN                InstallStopIndex,
-  IN INTN                NotifyStartIndex,
-  IN INTN                NotifyStopIndex
+  IN UINTN              NotifyType,
+  IN INTN               InstallStartIndex,
+  IN INTN               InstallStopIndex,
+  IN INTN               NotifyStartIndex,
+  IN INTN               NotifyStopIndex
   );
 
 /**
@@ -689,13 +690,14 @@ ProcessNotify (
 **/
 VOID
 ProcessPpiListFromSec (
-  IN CONST EFI_PEI_SERVICES         **PeiServices,
-  IN CONST EFI_PEI_PPI_DESCRIPTOR   *PpiList
+  IN CONST EFI_PEI_SERVICES        **PeiServices,
+  IN CONST EFI_PEI_PPI_DESCRIPTOR  *PpiList
   );
 
 //
 // Boot mode support functions
 //
+
 /**
   This service enables PEIMs to ascertain the present value of the boot mode.
 
@@ -727,12 +729,13 @@ EFI_STATUS
 EFIAPI
 PeiSetBootMode (
   IN CONST EFI_PEI_SERVICES  **PeiServices,
-  IN EFI_BOOT_MODE     BootMode
+  IN EFI_BOOT_MODE           BootMode
   );
 
 //
 // Security support functions
 //
+
 /**
 
   Initialize the security services.
@@ -744,8 +747,8 @@ PeiSetBootMode (
 **/
 VOID
 InitializeSecurityServices (
-  IN EFI_PEI_SERVICES  **PeiServices,
-  IN PEI_CORE_INSTANCE *OldCoreData
+  IN EFI_PEI_SERVICES   **PeiServices,
+  IN PEI_CORE_INSTANCE  *OldCoreData
   );
 
 /**
@@ -776,10 +779,10 @@ VerifyFv (
 **/
 EFI_STATUS
 VerifyPeim (
-  IN PEI_CORE_INSTANCE      *PrivateData,
-  IN EFI_PEI_FV_HANDLE      VolumeHandle,
-  IN EFI_PEI_FILE_HANDLE    FileHandle,
-  IN UINT32                 AuthenticationStatus
+  IN PEI_CORE_INSTANCE    *PrivateData,
+  IN EFI_PEI_FV_HANDLE    VolumeHandle,
+  IN EFI_PEI_FILE_HANDLE  FileHandle,
+  IN UINT32               AuthenticationStatus
   );
 
 /**
@@ -799,7 +802,7 @@ EFI_STATUS
 EFIAPI
 PeiGetHobList (
   IN CONST EFI_PEI_SERVICES  **PeiServices,
-  IN OUT VOID          **HobList
+  IN OUT VOID                **HobList
   );
 
 /**
@@ -820,9 +823,9 @@ EFI_STATUS
 EFIAPI
 PeiCreateHob (
   IN CONST EFI_PEI_SERVICES  **PeiServices,
-  IN UINT16            Type,
-  IN UINT16            Length,
-  IN OUT VOID          **Hob
+  IN UINT16                  Type,
+  IN UINT16                  Length,
+  IN OUT VOID                **Hob
   );
 
 /**
@@ -855,14 +858,14 @@ PeiCoreBuildHobHandoffInfoTable (
 **/
 EFI_STATUS
 PeiInstallSecHobData (
-  IN CONST EFI_PEI_SERVICES     **PeiServices,
-  IN EFI_HOB_GENERIC_HEADER     *SecHobList
+  IN CONST EFI_PEI_SERVICES  **PeiServices,
+  IN EFI_HOB_GENERIC_HEADER  *SecHobList
   );
 
-
 //
 // FFS Fw Volume support functions
 //
+
 /**
   Searches for the next matching file in the firmware volume.
 
@@ -882,10 +885,10 @@ PeiInstallSecHobData (
 EFI_STATUS
 EFIAPI
 PeiFfsFindNextFile (
-  IN CONST EFI_PEI_SERVICES      **PeiServices,
-  IN UINT8                       SearchType,
-  IN EFI_PEI_FV_HANDLE           FvHandle,
-  IN OUT EFI_PEI_FILE_HANDLE     *FileHandle
+  IN CONST EFI_PEI_SERVICES   **PeiServices,
+  IN UINT8                    SearchType,
+  IN EFI_PEI_FV_HANDLE        FvHandle,
+  IN OUT EFI_PEI_FILE_HANDLE  *FileHandle
   );
 
 /**
@@ -935,10 +938,10 @@ ProcessSection (
 EFI_STATUS
 EFIAPI
 PeiFfsFindSectionData (
-  IN CONST EFI_PEI_SERVICES    **PeiServices,
-  IN     EFI_SECTION_TYPE      SectionType,
-  IN     EFI_PEI_FILE_HANDLE   FileHandle,
-  OUT VOID                     **SectionData
+  IN CONST EFI_PEI_SERVICES   **PeiServices,
+  IN     EFI_SECTION_TYPE     SectionType,
+  IN     EFI_PEI_FILE_HANDLE  FileHandle,
+  OUT VOID                    **SectionData
   );
 
 /**
@@ -958,12 +961,12 @@ PeiFfsFindSectionData (
 EFI_STATUS
 EFIAPI
 PeiFfsFindSectionData3 (
-  IN CONST EFI_PEI_SERVICES    **PeiServices,
-  IN     EFI_SECTION_TYPE      SectionType,
-  IN     UINTN                 SectionInstance,
-  IN     EFI_PEI_FILE_HANDLE   FileHandle,
-  OUT VOID                     **SectionData,
-  OUT UINT32                   *AuthenticationStatus
+  IN CONST EFI_PEI_SERVICES   **PeiServices,
+  IN     EFI_SECTION_TYPE     SectionType,
+  IN     UINTN                SectionInstance,
+  IN     EFI_PEI_FILE_HANDLE  FileHandle,
+  OUT VOID                    **SectionData,
+  OUT UINT32                  *AuthenticationStatus
   );
 
 /**
@@ -982,14 +985,15 @@ PeiFfsFindSectionData3 (
 EFI_STATUS
 EFIAPI
 PeiFfsFindNextVolume (
-  IN CONST EFI_PEI_SERVICES          **PeiServices,
-  IN UINTN                           Instance,
-  IN OUT EFI_PEI_FV_HANDLE           *VolumeHandle
+  IN CONST EFI_PEI_SERVICES  **PeiServices,
+  IN UINTN                   Instance,
+  IN OUT EFI_PEI_FV_HANDLE   *VolumeHandle
   );
 
 //
 // Memory support functions
 //
+
 /**
 
   Initialize the memory services.
@@ -1023,9 +1027,9 @@ InitializeMemoryServices (
 EFI_STATUS
 EFIAPI
 PeiInstallPeiMemory (
-  IN CONST EFI_PEI_SERVICES      **PeiServices,
-  IN EFI_PHYSICAL_ADDRESS  MemoryBegin,
-  IN UINT64                MemoryLength
+  IN CONST EFI_PEI_SERVICES  **PeiServices,
+  IN EFI_PHYSICAL_ADDRESS    MemoryBegin,
+  IN UINT64                  MemoryLength
   );
 
 /**
@@ -1038,8 +1042,8 @@ PeiInstallPeiMemory (
 **/
 VOID
 MigrateMemoryPages (
-  IN PEI_CORE_INSTANCE      *Private,
-  IN BOOLEAN                TemporaryRamMigrated
+  IN PEI_CORE_INSTANCE  *Private,
+  IN BOOLEAN            TemporaryRamMigrated
   );
 
 /**
@@ -1050,7 +1054,7 @@ MigrateMemoryPages (
 **/
 VOID
 RemoveFvHobsInTemporaryMemory (
-  IN PEI_CORE_INSTANCE        *Private
+  IN PEI_CORE_INSTANCE  *Private
   );
 
 /**
@@ -1064,9 +1068,9 @@ RemoveFvHobsInTemporaryMemory (
 **/
 VOID
 ConvertFvHob (
-  IN PEI_CORE_INSTANCE          *PrivateData,
-  IN UINTN                      OrgFvHandle,
-  IN UINTN                      FvHandle
+  IN PEI_CORE_INSTANCE  *PrivateData,
+  IN UINTN              OrgFvHandle,
+  IN UINTN              FvHandle
   );
 
 /**
@@ -1078,7 +1082,7 @@ ConvertFvHob (
 **/
 VOID
 ConvertMemoryAllocationHobs (
-  IN PEI_CORE_INSTANCE          *PrivateData
+  IN PEI_CORE_INSTANCE  *PrivateData
   );
 
 /**
@@ -1106,10 +1110,10 @@ ConvertMemoryAllocationHobs (
 EFI_STATUS
 EFIAPI
 PeiAllocatePages (
-  IN CONST EFI_PEI_SERVICES     **PeiServices,
-  IN       EFI_MEMORY_TYPE      MemoryType,
-  IN       UINTN                Pages,
-  OUT      EFI_PHYSICAL_ADDRESS *Memory
+  IN CONST EFI_PEI_SERVICES      **PeiServices,
+  IN       EFI_MEMORY_TYPE       MemoryType,
+  IN       UINTN                 Pages,
+  OUT      EFI_PHYSICAL_ADDRESS  *Memory
   );
 
 /**
@@ -1128,9 +1132,9 @@ PeiAllocatePages (
 EFI_STATUS
 EFIAPI
 PeiFreePages (
-  IN CONST EFI_PEI_SERVICES     **PeiServices,
-  IN EFI_PHYSICAL_ADDRESS       Memory,
-  IN UINTN                      Pages
+  IN CONST EFI_PEI_SERVICES  **PeiServices,
+  IN EFI_PHYSICAL_ADDRESS    Memory,
+  IN UINTN                   Pages
   );
 
 /**
@@ -1150,9 +1154,9 @@ PeiFreePages (
 EFI_STATUS
 EFIAPI
 PeiAllocatePool (
-  IN CONST EFI_PEI_SERVICES           **PeiServices,
-  IN UINTN                      Size,
-  OUT VOID                      **Buffer
+  IN CONST EFI_PEI_SERVICES  **PeiServices,
+  IN UINTN                   Size,
+  OUT VOID                   **Buffer
   );
 
 /**
@@ -1173,11 +1177,11 @@ PeiAllocatePool (
 **/
 EFI_STATUS
 PeiLoadImage (
-  IN  CONST EFI_PEI_SERVICES      **PeiServices,
-  IN  EFI_PEI_FILE_HANDLE         FileHandle,
-  IN  UINT8                       PeimState,
-  OUT    EFI_PHYSICAL_ADDRESS     *EntryPoint,
-  OUT    UINT32                   *AuthenticationState
+  IN  CONST EFI_PEI_SERVICES   **PeiServices,
+  IN  EFI_PEI_FILE_HANDLE      FileHandle,
+  IN  UINT8                    PeimState,
+  OUT    EFI_PHYSICAL_ADDRESS  *EntryPoint,
+  OUT    UINT32                *AuthenticationState
   );
 
 /**
@@ -1199,12 +1203,12 @@ PeiLoadImage (
 EFI_STATUS
 EFIAPI
 PeiReportStatusCode (
-  IN CONST EFI_PEI_SERVICES         **PeiServices,
-  IN EFI_STATUS_CODE_TYPE     CodeType,
-  IN EFI_STATUS_CODE_VALUE    Value,
-  IN UINT32                   Instance,
-  IN CONST EFI_GUID                 *CallerId,
-  IN CONST EFI_STATUS_CODE_DATA     *Data OPTIONAL
+  IN CONST EFI_PEI_SERVICES      **PeiServices,
+  IN EFI_STATUS_CODE_TYPE        CodeType,
+  IN EFI_STATUS_CODE_VALUE       Value,
+  IN UINT32                      Instance,
+  IN CONST EFI_GUID              *CallerId,
+  IN CONST EFI_STATUS_CODE_DATA  *Data OPTIONAL
   );
 
 /**
@@ -1222,7 +1226,7 @@ PeiReportStatusCode (
 EFI_STATUS
 EFIAPI
 PeiResetSystem (
-  IN CONST EFI_PEI_SERVICES   **PeiServices
+  IN CONST EFI_PEI_SERVICES  **PeiServices
   );
 
 /**
@@ -1241,10 +1245,10 @@ PeiResetSystem (
 VOID
 EFIAPI
 PeiResetSystem2 (
-  IN EFI_RESET_TYPE     ResetType,
-  IN EFI_STATUS         ResetStatus,
-  IN UINTN              DataSize,
-  IN VOID               *ResetData OPTIONAL
+  IN EFI_RESET_TYPE  ResetType,
+  IN EFI_STATUS      ResetStatus,
+  IN UINTN           DataSize,
+  IN VOID            *ResetData OPTIONAL
   );
 
 /**
@@ -1258,8 +1262,8 @@ PeiResetSystem2 (
 **/
 VOID
 PeiInitializeFv (
-  IN  PEI_CORE_INSTANCE           *PrivateData,
-  IN CONST EFI_SEC_PEI_HAND_OFF   *SecCoreData
+  IN  PEI_CORE_INSTANCE          *PrivateData,
+  IN CONST EFI_SEC_PEI_HAND_OFF  *SecCoreData
   );
 
 /**
@@ -1275,9 +1279,9 @@ PeiInitializeFv (
 EFI_STATUS
 EFIAPI
 FirmwareVolumeInfoPpiNotifyCallback (
-  IN EFI_PEI_SERVICES              **PeiServices,
-  IN EFI_PEI_NOTIFY_DESCRIPTOR     *NotifyDescriptor,
-  IN VOID                          *Ppi
+  IN EFI_PEI_SERVICES           **PeiServices,
+  IN EFI_PEI_NOTIFY_DESCRIPTOR  *NotifyDescriptor,
+  IN VOID                       *Ppi
   );
 
 /**
@@ -1296,9 +1300,9 @@ FirmwareVolumeInfoPpiNotifyCallback (
 EFI_STATUS
 EFIAPI
 PeiFfsFindFileByName (
-  IN  CONST EFI_GUID        *FileName,
-  IN  EFI_PEI_FV_HANDLE     VolumeHandle,
-  OUT EFI_PEI_FILE_HANDLE   *FileHandle
+  IN  CONST EFI_GUID       *FileName,
+  IN  EFI_PEI_FV_HANDLE    VolumeHandle,
+  OUT EFI_PEI_FILE_HANDLE  *FileHandle
   );
 
 /**
@@ -1368,7 +1372,7 @@ PeiFfsGetVolumeInfo (
 EFI_STATUS
 EFIAPI
 PeiRegisterForShadow (
-  IN EFI_PEI_FILE_HANDLE       FileHandle
+  IN EFI_PEI_FILE_HANDLE  FileHandle
   );
 
 /**
@@ -1383,8 +1387,8 @@ PeiRegisterForShadow (
 **/
 VOID
 InitializeImageServices (
-  IN  PEI_CORE_INSTANCE   *PrivateData,
-  IN  PEI_CORE_INSTANCE   *OldCoreData
+  IN  PEI_CORE_INSTANCE  *PrivateData,
+  IN  PEI_CORE_INSTANCE  *OldCoreData
   );
 
 /**
@@ -1399,8 +1403,8 @@ InitializeImageServices (
 **/
 EFI_STATUS
 LoadAndRelocatePeCoffImageInPlace (
-  IN  VOID    *Pe32Data,
-  IN  VOID    *ImageAddress
+  IN  VOID  *Pe32Data,
+  IN  VOID  *ImageAddress
   );
 
 /**
@@ -1415,8 +1419,8 @@ LoadAndRelocatePeCoffImageInPlace (
 **/
 EFI_STATUS
 PeiGetPe32Data (
-  IN     EFI_PEI_FILE_HANDLE          FileHandle,
-  OUT    VOID                         **Pe32Data
+  IN     EFI_PEI_FILE_HANDLE  FileHandle,
+  OUT    VOID                 **Pe32Data
   );
 
 /**
@@ -1437,8 +1441,8 @@ EFIAPI
 PeiLoadImageLoadImageWrapper (
   IN     CONST EFI_PEI_LOAD_FILE_PPI  *This,
   IN     EFI_PEI_FILE_HANDLE          FileHandle,
-  OUT    EFI_PHYSICAL_ADDRESS         *ImageAddressArg,  OPTIONAL
-  OUT    UINT64                       *ImageSizeArg,     OPTIONAL
+  OUT    EFI_PHYSICAL_ADDRESS         *ImageAddressArg   OPTIONAL,
+  OUT    UINT64                       *ImageSizeArg      OPTIONAL,
   OUT    EFI_PHYSICAL_ADDRESS         *EntryPoint,
   OUT    UINT32                       *AuthenticationState
   );
@@ -1478,9 +1482,9 @@ SecurityPpiNotifyCallback (
 **/
 EFI_STATUS
 ProcessFvFile (
-  IN  PEI_CORE_INSTANCE           *PrivateData,
-  IN  PEI_CORE_FV_HANDLE          *ParentFvCoreHandle,
-  IN  EFI_PEI_FILE_HANDLE         ParentFvFileHandle
+  IN  PEI_CORE_INSTANCE    *PrivateData,
+  IN  PEI_CORE_FV_HANDLE   *ParentFvCoreHandle,
+  IN  EFI_PEI_FILE_HANDLE  ParentFvFileHandle
   );
 
 /**
@@ -1526,12 +1530,12 @@ FindNextCoreFvHandle (
 EFI_STATUS
 EFIAPI
 PeiDefaultMemRead (
-  IN  CONST EFI_PEI_SERVICES            **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI          *This,
-  IN  EFI_PEI_CPU_IO_PPI_WIDTH          Width,
-  IN  UINT64                            Address,
-  IN  UINTN                             Count,
-  IN  OUT VOID                          *Buffer
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  EFI_PEI_CPU_IO_PPI_WIDTH  Width,
+  IN  UINT64                    Address,
+  IN  UINTN                     Count,
+  IN  OUT VOID                  *Buffer
   );
 
 /**
@@ -1556,12 +1560,12 @@ PeiDefaultMemRead (
 EFI_STATUS
 EFIAPI
 PeiDefaultMemWrite (
-  IN  CONST EFI_PEI_SERVICES            **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI          *This,
-  IN  EFI_PEI_CPU_IO_PPI_WIDTH          Width,
-  IN  UINT64                            Address,
-  IN  UINTN                             Count,
-  IN  OUT VOID                          *Buffer
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  EFI_PEI_CPU_IO_PPI_WIDTH  Width,
+  IN  UINT64                    Address,
+  IN  UINTN                     Count,
+  IN  OUT VOID                  *Buffer
   );
 
 /**
@@ -1585,12 +1589,12 @@ PeiDefaultMemWrite (
 EFI_STATUS
 EFIAPI
 PeiDefaultIoRead (
-  IN      CONST EFI_PEI_SERVICES          **PeiServices,
-  IN      CONST EFI_PEI_CPU_IO_PPI        *This,
-  IN      EFI_PEI_CPU_IO_PPI_WIDTH        Width,
-  IN      UINT64                          Address,
-  IN      UINTN                           Count,
-  IN OUT  VOID                            *Buffer
+  IN      CONST EFI_PEI_SERVICES    **PeiServices,
+  IN      CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN      EFI_PEI_CPU_IO_PPI_WIDTH  Width,
+  IN      UINT64                    Address,
+  IN      UINTN                     Count,
+  IN OUT  VOID                      *Buffer
   );
 
 /**
@@ -1614,12 +1618,12 @@ PeiDefaultIoRead (
 EFI_STATUS
 EFIAPI
 PeiDefaultIoWrite (
-  IN      CONST EFI_PEI_SERVICES          **PeiServices,
-  IN      CONST EFI_PEI_CPU_IO_PPI        *This,
-  IN      EFI_PEI_CPU_IO_PPI_WIDTH        Width,
-  IN      UINT64                          Address,
-  IN      UINTN                           Count,
-  IN OUT  VOID                            *Buffer
+  IN      CONST EFI_PEI_SERVICES    **PeiServices,
+  IN      CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN      EFI_PEI_CPU_IO_PPI_WIDTH  Width,
+  IN      UINT64                    Address,
+  IN      UINTN                     Count,
+  IN OUT  VOID                      *Buffer
   );
 
 /**
@@ -1637,9 +1641,9 @@ PeiDefaultIoWrite (
 UINT8
 EFIAPI
 PeiDefaultIoRead8 (
-  IN  CONST EFI_PEI_SERVICES      **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI    *This,
-  IN  UINT64                      Address
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address
   );
 
 /**
@@ -1657,9 +1661,9 @@ PeiDefaultIoRead8 (
 UINT16
 EFIAPI
 PeiDefaultIoRead16 (
-  IN  CONST EFI_PEI_SERVICES      **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI    *This,
-  IN  UINT64                      Address
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address
   );
 
 /**
@@ -1677,9 +1681,9 @@ PeiDefaultIoRead16 (
 UINT32
 EFIAPI
 PeiDefaultIoRead32 (
-  IN  CONST EFI_PEI_SERVICES      **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI    *This,
-  IN  UINT64                      Address
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address
   );
 
 /**
@@ -1697,9 +1701,9 @@ PeiDefaultIoRead32 (
 UINT64
 EFIAPI
 PeiDefaultIoRead64 (
-  IN  CONST EFI_PEI_SERVICES      **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI    *This,
-  IN  UINT64                      Address
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address
   );
 
 /**
@@ -1713,10 +1717,10 @@ PeiDefaultIoRead64 (
 VOID
 EFIAPI
 PeiDefaultIoWrite8 (
-  IN  CONST EFI_PEI_SERVICES      **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI    *This,
-  IN  UINT64                      Address,
-  IN  UINT8                       Data
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address,
+  IN  UINT8                     Data
   );
 
 /**
@@ -1730,10 +1734,10 @@ PeiDefaultIoWrite8 (
 VOID
 EFIAPI
 PeiDefaultIoWrite16 (
-  IN  CONST EFI_PEI_SERVICES      **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI    *This,
-  IN  UINT64                      Address,
-  IN  UINT16                      Data
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address,
+  IN  UINT16                    Data
   );
 
 /**
@@ -1747,10 +1751,10 @@ PeiDefaultIoWrite16 (
 VOID
 EFIAPI
 PeiDefaultIoWrite32 (
-  IN  CONST EFI_PEI_SERVICES      **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI    *This,
-  IN  UINT64                      Address,
-  IN  UINT32                      Data
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address,
+  IN  UINT32                    Data
   );
 
 /**
@@ -1764,10 +1768,10 @@ PeiDefaultIoWrite32 (
 VOID
 EFIAPI
 PeiDefaultIoWrite64 (
-  IN  CONST EFI_PEI_SERVICES      **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI    *This,
-  IN  UINT64                      Address,
-  IN  UINT64                      Data
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address,
+  IN  UINT64                    Data
   );
 
 /**
@@ -1786,9 +1790,9 @@ PeiDefaultIoWrite64 (
 UINT8
 EFIAPI
 PeiDefaultMemRead8 (
-  IN  CONST EFI_PEI_SERVICES      **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI    *This,
-  IN  UINT64                      Address
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address
   );
 
 /**
@@ -1807,9 +1811,9 @@ PeiDefaultMemRead8 (
 UINT16
 EFIAPI
 PeiDefaultMemRead16 (
-  IN  CONST EFI_PEI_SERVICES      **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI    *This,
-  IN  UINT64                      Address
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address
   );
 
 /**
@@ -1828,9 +1832,9 @@ PeiDefaultMemRead16 (
 UINT32
 EFIAPI
 PeiDefaultMemRead32 (
-  IN  CONST EFI_PEI_SERVICES      **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI    *This,
-  IN  UINT64                      Address
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address
   );
 
 /**
@@ -1849,9 +1853,9 @@ PeiDefaultMemRead32 (
 UINT64
 EFIAPI
 PeiDefaultMemRead64 (
-  IN  CONST EFI_PEI_SERVICES      **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI    *This,
-  IN  UINT64                      Address
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address
   );
 
 /**
@@ -1866,10 +1870,10 @@ PeiDefaultMemRead64 (
 VOID
 EFIAPI
 PeiDefaultMemWrite8 (
-  IN  CONST EFI_PEI_SERVICES        **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI      *This,
-  IN  UINT64                        Address,
-  IN  UINT8                         Data
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address,
+  IN  UINT8                     Data
   );
 
 /**
@@ -1884,10 +1888,10 @@ PeiDefaultMemWrite8 (
 VOID
 EFIAPI
 PeiDefaultMemWrite16 (
-  IN  CONST EFI_PEI_SERVICES        **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI      *This,
-  IN  UINT64                        Address,
-  IN  UINT16                        Data
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address,
+  IN  UINT16                    Data
   );
 
 /**
@@ -1902,10 +1906,10 @@ PeiDefaultMemWrite16 (
 VOID
 EFIAPI
 PeiDefaultMemWrite32 (
-  IN  CONST EFI_PEI_SERVICES        **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI      *This,
-  IN  UINT64                        Address,
-  IN  UINT32                        Data
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address,
+  IN  UINT32                    Data
   );
 
 /**
@@ -1920,13 +1924,13 @@ PeiDefaultMemWrite32 (
 VOID
 EFIAPI
 PeiDefaultMemWrite64 (
-  IN  CONST EFI_PEI_SERVICES        **PeiServices,
-  IN  CONST EFI_PEI_CPU_IO_PPI      *This,
-  IN  UINT64                        Address,
-  IN  UINT64                        Data
+  IN  CONST EFI_PEI_SERVICES    **PeiServices,
+  IN  CONST EFI_PEI_CPU_IO_PPI  *This,
+  IN  UINT64                    Address,
+  IN  UINT64                    Data
   );
 
-extern EFI_PEI_CPU_IO_PPI gPeiDefaultCpuIoPpi;
+extern EFI_PEI_CPU_IO_PPI  gPeiDefaultCpuIoPpi;
 
 //
 // Default EFI_PEI_PCI_CFG2_PPI support for EFI_PEI_SERVICES table when PeiCore initialization.
@@ -1954,11 +1958,11 @@ extern EFI_PEI_CPU_IO_PPI gPeiDefaultCpuIoPpi;
 EFI_STATUS
 EFIAPI
 PeiDefaultPciCfg2Read (
-  IN CONST  EFI_PEI_SERVICES          **PeiServices,
-  IN CONST  EFI_PEI_PCI_CFG2_PPI      *This,
-  IN        EFI_PEI_PCI_CFG_PPI_WIDTH Width,
-  IN        UINT64                    Address,
-  IN OUT    VOID                      *Buffer
+  IN CONST  EFI_PEI_SERVICES           **PeiServices,
+  IN CONST  EFI_PEI_PCI_CFG2_PPI       *This,
+  IN        EFI_PEI_PCI_CFG_PPI_WIDTH  Width,
+  IN        UINT64                     Address,
+  IN OUT    VOID                       *Buffer
   );
 
 /**
@@ -1982,11 +1986,11 @@ PeiDefaultPciCfg2Read (
 EFI_STATUS
 EFIAPI
 PeiDefaultPciCfg2Write (
-  IN CONST  EFI_PEI_SERVICES          **PeiServices,
-  IN CONST  EFI_PEI_PCI_CFG2_PPI      *This,
-  IN        EFI_PEI_PCI_CFG_PPI_WIDTH Width,
-  IN        UINT64                    Address,
-  IN OUT    VOID                      *Buffer
+  IN CONST  EFI_PEI_SERVICES           **PeiServices,
+  IN CONST  EFI_PEI_PCI_CFG2_PPI       *This,
+  IN        EFI_PEI_PCI_CFG_PPI_WIDTH  Width,
+  IN        UINT64                     Address,
+  IN OUT    VOID                       *Buffer
   );
 
 /**
@@ -2011,15 +2015,15 @@ PeiDefaultPciCfg2Write (
 EFI_STATUS
 EFIAPI
 PeiDefaultPciCfg2Modify (
-  IN CONST  EFI_PEI_SERVICES          **PeiServices,
-  IN CONST  EFI_PEI_PCI_CFG2_PPI      *This,
-  IN        EFI_PEI_PCI_CFG_PPI_WIDTH Width,
-  IN        UINT64                    Address,
-  IN        VOID                      *SetBits,
-  IN        VOID                      *ClearBits
+  IN CONST  EFI_PEI_SERVICES           **PeiServices,
+  IN CONST  EFI_PEI_PCI_CFG2_PPI       *This,
+  IN        EFI_PEI_PCI_CFG_PPI_WIDTH  Width,
+  IN        UINT64                     Address,
+  IN        VOID                       *SetBits,
+  IN        VOID                       *ClearBits
   );
 
-extern EFI_PEI_PCI_CFG2_PPI gPeiDefaultPciCfg2Ppi;
+extern EFI_PEI_PCI_CFG2_PPI  gPeiDefaultPciCfg2Ppi;
 
 /**
   After PeiCore image is shadowed into permanent memory, all build-in FvPpi should
@@ -2031,7 +2035,7 @@ extern EFI_PEI_PCI_CFG2_PPI gPeiDefaultPciCfg2Ppi;
 **/
 VOID
 PeiReinitializeFv (
-  IN  PEI_CORE_INSTANCE           *PrivateData
+  IN  PEI_CORE_INSTANCE  *PrivateData
   );
 
 #endif
