@@ -9,6 +9,7 @@
 **/
 
 #include <Library/MemoryAllocationLib.h>
+#include <Library/PcdLib.h>
 
 #include "VirtioGpu.h"
 
@@ -192,6 +193,106 @@ STATIC CONST GOP_RESOLUTION  mGopResolutions[] = {
 #define VGPU_GOP_FROM_GOP(GopPointer) \
           CR (GopPointer, VGPU_GOP, Gop, VGPU_GOP_SIG)
 
+STATIC
+VOID
+EFIAPI
+GopNativeResolution (
+  IN  VGPU_GOP  *VgpuGop,
+  OUT UINT32    *XRes,
+  OUT UINT32    *YRes
+  )
+{
+  volatile VIRTIO_GPU_RESP_DISPLAY_INFO  DisplayInfo;
+  EFI_STATUS                             Status;
+  UINTN                                  Index;
+
+  Status = VirtioGpuGetDisplayInfo (VgpuGop->ParentBus, &DisplayInfo);
+  if (Status != EFI_SUCCESS) {
+    return;
+  }
+
+  for (Index = 0; Index < VIRTIO_GPU_MAX_SCANOUTS; Index++) {
+    if (!DisplayInfo.Pmodes[Index].Enabled ||
+        !DisplayInfo.Pmodes[Index].Rectangle.Width ||
+        !DisplayInfo.Pmodes[Index].Rectangle.Height)
+    {
+      continue;
+    }
+
+    DEBUG ((
+      DEBUG_INFO,
+      "%a: #%d: %dx%d\n",
+      __FUNCTION__,
+      Index,
+      DisplayInfo.Pmodes[Index].Rectangle.Width,
+      DisplayInfo.Pmodes[Index].Rectangle.Height
+      ));
+    if ((*XRes == 0) || (*YRes == 0)) {
+      *XRes = DisplayInfo.Pmodes[Index].Rectangle.Width;
+      *YRes = DisplayInfo.Pmodes[Index].Rectangle.Height;
+    }
+  }
+}
+
+STATIC
+VOID
+EFIAPI
+GopInitialize (
+  IN  EFI_GRAPHICS_OUTPUT_PROTOCOL  *This
+  )
+{
+  VGPU_GOP    *VgpuGop;
+  EFI_STATUS  Status;
+  UINT32      XRes = 0, YRes = 0, Index;
+
+  VgpuGop = VGPU_GOP_FROM_GOP (This);
+
+  //
+  // Set up the Gop -> GopMode -> GopModeInfo pointer chain, and the other
+  // (nonzero) constant fields.
+  //
+  // No direct framebuffer access is supported, only Blt() is.
+  //
+  VgpuGop->Gop.Mode = &VgpuGop->GopMode;
+
+  VgpuGop->GopMode.MaxMode    = (UINT32)(ARRAY_SIZE (mGopResolutions));
+  VgpuGop->GopMode.Info       = &VgpuGop->GopModeInfo;
+  VgpuGop->GopMode.SizeOfInfo = sizeof VgpuGop->GopModeInfo;
+
+  VgpuGop->GopModeInfo.PixelFormat = PixelBltOnly;
+
+  //
+  // query host for display resolution
+  //
+  GopNativeResolution (VgpuGop, &XRes, &YRes);
+  if ((XRes == 0) || (YRes == 0)) {
+    return;
+  }
+
+  if (PcdGet8 (PcdVideoResolutionSource) == 0) {
+    Status = PcdSet32S (PcdVideoHorizontalResolution, XRes);
+    ASSERT_RETURN_ERROR (Status);
+    Status = PcdSet32S (PcdVideoVerticalResolution, YRes);
+    ASSERT_RETURN_ERROR (Status);
+    Status = PcdSet8S (PcdVideoResolutionSource, 2);
+    ASSERT_RETURN_ERROR (Status);
+  }
+
+  VgpuGop->NativeXRes = XRes;
+  VgpuGop->NativeYRes = YRes;
+  for (Index = 0; Index < ARRAY_SIZE (mGopResolutions); Index++) {
+    if ((mGopResolutions[Index].Width == XRes) &&
+        (mGopResolutions[Index].Height == YRes))
+    {
+      // native resolution already is in mode list
+      return;
+    }
+  }
+
+  // add to mode list
+  VgpuGop->GopMode.MaxMode++;
+}
+
 //
 // EFI_GRAPHICS_OUTPUT_PROTOCOL member functions.
 //
@@ -207,7 +308,7 @@ GopQueryMode (
 {
   EFI_GRAPHICS_OUTPUT_MODE_INFORMATION  *GopModeInfo;
 
-  if (ModeNumber >= ARRAY_SIZE (mGopResolutions)) {
+  if (ModeNumber >= This->Mode->MaxMode) {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -216,10 +317,17 @@ GopQueryMode (
     return EFI_OUT_OF_RESOURCES;
   }
 
-  GopModeInfo->HorizontalResolution = mGopResolutions[ModeNumber].Width;
-  GopModeInfo->VerticalResolution   = mGopResolutions[ModeNumber].Height;
-  GopModeInfo->PixelFormat          = PixelBltOnly;
-  GopModeInfo->PixelsPerScanLine    = mGopResolutions[ModeNumber].Width;
+  if (ModeNumber < ARRAY_SIZE (mGopResolutions)) {
+    GopModeInfo->HorizontalResolution = mGopResolutions[ModeNumber].Width;
+    GopModeInfo->VerticalResolution   = mGopResolutions[ModeNumber].Height;
+  } else {
+    VGPU_GOP  *VgpuGop = VGPU_GOP_FROM_GOP (This);
+    GopModeInfo->HorizontalResolution = VgpuGop->NativeXRes;
+    GopModeInfo->VerticalResolution   = VgpuGop->NativeYRes;
+  }
+
+  GopModeInfo->PixelFormat       = PixelBltOnly;
+  GopModeInfo->PixelsPerScanLine = GopModeInfo->HorizontalResolution;
 
   *SizeOfInfo = sizeof *GopModeInfo;
   *Info       = GopModeInfo;
@@ -234,19 +342,27 @@ GopSetMode (
   IN  UINT32                        ModeNumber
   )
 {
-  VGPU_GOP              *VgpuGop;
-  UINT32                NewResourceId;
-  UINTN                 NewNumberOfBytes;
-  UINTN                 NewNumberOfPages;
-  VOID                  *NewBackingStore;
-  EFI_PHYSICAL_ADDRESS  NewBackingStoreDeviceAddress;
-  VOID                  *NewBackingStoreMap;
+  VGPU_GOP                              *VgpuGop;
+  UINT32                                NewResourceId;
+  UINTN                                 NewNumberOfBytes;
+  UINTN                                 NewNumberOfPages;
+  VOID                                  *NewBackingStore;
+  EFI_PHYSICAL_ADDRESS                  NewBackingStoreDeviceAddress;
+  VOID                                  *NewBackingStoreMap;
+  UINTN                                 SizeOfInfo;
+  EFI_GRAPHICS_OUTPUT_MODE_INFORMATION  *GopModeInfo;
 
   EFI_STATUS  Status;
   EFI_STATUS  Status2;
 
-  if (ModeNumber >= ARRAY_SIZE (mGopResolutions)) {
-    return EFI_UNSUPPORTED;
+  if (!This->Mode) {
+    // SetMode() call in InitVgpuGop() triggers this.
+    GopInitialize (This);
+  }
+
+  Status = GopQueryMode (This, ModeNumber, &SizeOfInfo, &GopModeInfo);
+  if (Status != EFI_SUCCESS) {
+    return Status;
   }
 
   VgpuGop = VGPU_GOP_FROM_GOP (This);
@@ -256,20 +372,6 @@ GopSetMode (
   // calls.
   //
   if (VgpuGop->ResourceId == 0) {
-    //
-    // Set up the Gop -> GopMode -> GopModeInfo pointer chain, and the other
-    // (nonzero) constant fields.
-    //
-    // No direct framebuffer access is supported, only Blt() is.
-    //
-    VgpuGop->Gop.Mode = &VgpuGop->GopMode;
-
-    VgpuGop->GopMode.MaxMode    = (UINT32)(ARRAY_SIZE (mGopResolutions));
-    VgpuGop->GopMode.Info       = &VgpuGop->GopModeInfo;
-    VgpuGop->GopMode.SizeOfInfo = sizeof VgpuGop->GopModeInfo;
-
-    VgpuGop->GopModeInfo.PixelFormat = PixelBltOnly;
-
     //
     // This is the first time we create a host side resource.
     //
@@ -292,8 +394,8 @@ GopSetMode (
              VgpuGop->ParentBus,                // VgpuDev
              NewResourceId,                     // ResourceId
              VirtioGpuFormatB8G8R8X8Unorm,      // Format
-             mGopResolutions[ModeNumber].Width, // Width
-             mGopResolutions[ModeNumber].Height // Height
+             GopModeInfo->HorizontalResolution, // Width
+             GopModeInfo->VerticalResolution    // Height
              );
   if (EFI_ERROR (Status)) {
     return Status;
@@ -303,8 +405,8 @@ GopSetMode (
   // Allocate, zero and map guest backing store, for bus master common buffer
   // operation.
   //
-  NewNumberOfBytes = mGopResolutions[ModeNumber].Width *
-                     mGopResolutions[ModeNumber].Height * sizeof (UINT32);
+  NewNumberOfBytes = GopModeInfo->HorizontalResolution *
+                     GopModeInfo->VerticalResolution * sizeof (UINT32);
   NewNumberOfPages = EFI_SIZE_TO_PAGES (NewNumberOfBytes);
   Status           = VirtioGpuAllocateZeroAndMapBackingStore (
                        VgpuGop->ParentBus,            // VgpuDev
@@ -337,8 +439,8 @@ GopSetMode (
              VgpuGop->ParentBus,                 // VgpuDev
              0,                                  // X
              0,                                  // Y
-             mGopResolutions[ModeNumber].Width,  // Width
-             mGopResolutions[ModeNumber].Height, // Height
+             GopModeInfo->HorizontalResolution,  // Width
+             GopModeInfo->VerticalResolution,    // Height
              0,                                  // ScanoutId
              NewResourceId                       // ResourceId
              );
@@ -356,8 +458,8 @@ GopSetMode (
                VgpuGop->ParentBus,                 // VgpuDev
                0,                                  // X
                0,                                  // Y
-               mGopResolutions[ModeNumber].Width,  // Width
-               mGopResolutions[ModeNumber].Height, // Height
+               GopModeInfo->HorizontalResolution,  // Width
+               GopModeInfo->VerticalResolution,    // Height
                NewResourceId                       // ResourceId
                );
     if (EFI_ERROR (Status)) {
@@ -367,13 +469,13 @@ GopSetMode (
       // therefore non-recoverable.
       //
       Status2 = VirtioGpuSetScanout (
-                  VgpuGop->ParentBus,                       // VgpuDev
-                  0,                                        // X
-                  0,                                        // Y
-                  mGopResolutions[This->Mode->Mode].Width,  // Width
-                  mGopResolutions[This->Mode->Mode].Height, // Height
-                  0,                                        // ScanoutId
-                  VgpuGop->ResourceId                       // ResourceId
+                  VgpuGop->ParentBus,                        // VgpuDev
+                  0,                                         // X
+                  0,                                         // Y
+                  VgpuGop->GopModeInfo.HorizontalResolution, // Width
+                  VgpuGop->GopModeInfo.VerticalResolution,   // Height
+                  0,                                         // ScanoutId
+                  VgpuGop->ResourceId                        // ResourceId
                   );
       ASSERT_EFI_ERROR (Status2);
       if (EFI_ERROR (Status2)) {
@@ -406,11 +508,9 @@ GopSetMode (
   //
   // Populate Mode and ModeInfo (mutable fields only).
   //
-  VgpuGop->GopMode.Mode                     = ModeNumber;
-  VgpuGop->GopModeInfo.HorizontalResolution =
-    mGopResolutions[ModeNumber].Width;
-  VgpuGop->GopModeInfo.VerticalResolution = mGopResolutions[ModeNumber].Height;
-  VgpuGop->GopModeInfo.PixelsPerScanLine  = mGopResolutions[ModeNumber].Width;
+  VgpuGop->GopMode.Mode = ModeNumber;
+  VgpuGop->GopModeInfo  = *GopModeInfo;
+  FreePool (GopModeInfo);
   return EFI_SUCCESS;
 
 DetachBackingStore:
@@ -435,6 +535,7 @@ DestroyHostResource:
     CpuDeadLoop ();
   }
 
+  FreePool (GopModeInfo);
   return Status;
 }
 
